==> snap_firmware_2.5.6-0.1.0-py2.py3-none-any.whl: snap_firmware_2_5_6/metadata.py <==
"""
(c) Copyright 2016 Synapse Wireless, Inc.

This file is copied into the firmware area for the package and
provides access to the firmware metadata.
"""

import json
import os

PREFIX_ALIASES = {'SM220_AES128_': 'SM220UF1_AES128_'}

_SUPPORTED_MODULE_PARTS_PLATFORM_STRING = {'RF100': 'RF100',
                                           'RF200P81': 'RF200',
                                           'RF200PD1': 'RF200',
                                           'RF200PF1': 'RF200',
                                           'RF200PU1': 'RF200',
                                           'RF220UF1': 'RF220',
                                           'RF266PC1': 'RF266',
                                           'RF266PU1': 'RF266',
                                           'SM200P81': 'SM200',
                                           'SM200PU1': 'SM200',
                                           'SM220UF1': 'SM220',
                                           'SS200': 'SS200'}

def get_supported_modules():
    return sorted(_SUPPORTED_MODULE_PARTS_PLATFORM_STRING.keys())

def get_module_platform_string(module):
    return _SUPPORTED_MODULE_PARTS_PLATFORM_STRING.get(module, None)

def _get_meta_dir():
    script_dir = os.path.dirname(os.path.realpath(__file__))
    return os.path.join(script_dir, "metadata")

def _load_metadata_json(module):
    metadata = None
    meta_dir = _get_meta_dir()
    for item in os.listdir(meta_dir):
        if item.find(module) == 0:
            fullname = os.path.join(meta_dir, item)
            if os.path.isfile(fullname):
                with open(fullname, "r") as f:
                    return json.load(f)

def get_module_cpu_id(module):
    metadata = _load_metadata_json(module)
    if metadata:
        return metadata.get("cpu", None)
    else:
        return None

def get_module_platform_id(module):
    metadata = _load_metadata_json(module)
    if metadata:
        return metadata.get("platform", None)
    else:
        return None

def get_module_num_builtins(module):
    metadata = _load_metadata_json(module)
    if metadata:
        return metadata.get("num_builtins", None)
    else:
        return None

def get_metadata(module, version, aes):

    md_filename = module + "_"
    if aes:
        md_filename += "AES128_"

    # Handle naming inconsistencies
    if md_filename in PREFIX_ALIASES:
        md_filename = PREFIX_ALIASES[md_filename]

    md_filename += "SnapV" + version + ".json"

    full_name = os.path.join(_get_meta_dir(), md_filename)

    if os.path.isfile(full_name):
        with open(full_name, "r") as f:
            return json.load(f)

    return None

==> snap_firmware_2.8.1-1.0.2-py2.py3-none-any.whl: snap_firmware_2_8_1/metadata.py <==
"""
(c) Copyright 2016 Synapse Wireless, Inc.

This file is copied into the firmware area for the package and 
provides access to the firmware metadata.
"""

import json
import os

PREFIX_ALIASES = {'SM220_AES128_': 'SM220UF1_AES128_'}

_SUPPORTED_MODULE_PARTS_PLATFORM_STRING = {'ATmega128RFA1': None,
                                           'ATmega1284RFR2': None,
                                           'ATmega128RFR2': None,
                                           'RF200P81': 'RF200',
                                           'RF200PD1': 'RF200',
                                           'RF200PF1': 'RF200',
                                           'RF200PU1': 'RF200',
                                           'RF220SU': 'RF220',
                                           'RF220SU_EU': 'RF220',
                                           'RF220UF1': 'RF220',
                                           'RF266PC1': 'RF266',
                                           'RF266PU1': 'RF266',
                                           'SM200P81': 'SM200',
                                           'SM200PU1': 'SM200',
                                           'SM220UF1': 'SM220',
                                           'SM220UF1_EU': 'SM220',
                                           'SN220': 'SN220',
                                           'SS200': 'SS200'}

def get_supported_modules():
    return sorted(_SUPPORTED_MODULE_PARTS_PLATFORM_STRING.keys())

def get_module_platform_string(module):
    return _SUPPORTED_MODULE_PARTS_PLATFORM_STRING.get(module, None)

def _get_meta_dir():
    script_dir = os.path.dirname(os.path.realpath(__file__))
    return os.path.join(script_dir, "metadata")

def _load_metadata_json(module):
    metadata = None
    meta_dir = _get_meta_dir()
    for item in os.listdir(meta_dir):
        if item.find(module) == 0:
            fullname = os.path.join(meta_dir, item)
            if os.path.isfile(fullname):
                with open(fullname, "r") as f:
                    return json.load(f)

def get_module_cpu_id(module):
    metadata = _load_metadata_json(module)
    if metadata:
        return metadata.get("cpu", None)
    else:
        return None

def get_module_platform_id(module):
    metadata = _load_metadata_json(module)
    if metadata:
        return metadata.get("platform", None)
    else:
        return None

def get_module_num_builtins(module):
    metadata = _load_metadata_json(module)
    if metadata:
        return metadata.get("num_builtins", None)
    else:
        return None

def get_metadata(module, version, aes):

    md_filename = module + "_"
    if aes:
        md_filename += "AES128_"

    # Handle naming inconsistencies
    if md_filename in PREFIX_ALIASES:
        md_filename = PREFIX_ALIASES[md_filename]

    md_filename += "SnapV" + version + ".json"

    full_name = os.path.join(_get_meta_dir(), md_filename)

    if os.path.isfile(full_name):
        with open(full_name, "r") as f:
            return json.load(f)

    return None
